@@ -35,9 +35,9 @@ function create_sahara_accounts {
     get_or_create_service "sahara" "data-processing" "Sahara Data Processing"
     get_or_create_endpoint "data-processing" \
         "$REGION_NAME" \
-        "$SAHARA_SERVICE_PROTOCOL://$SAHARA_SERVICE_HOST:$SAHARA_SERVICE_PORT/v1.1/\$(tenant_id)s" \
-        "$SAHARA_SERVICE_PROTOCOL://$SAHARA_SERVICE_HOST:$SAHARA_SERVICE_PORT/v1.1/\$(tenant_id)s" \
-        "$SAHARA_SERVICE_PROTOCOL://$SAHARA_SERVICE_HOST:$SAHARA_SERVICE_PORT/v1.1/\$(tenant_id)s"
+        "$SAHARA_SERVICE_PROTOCOL://$SAHARA_SERVICE_HOST:$SAHARA_SERVICE_PORT" \
+        "$SAHARA_SERVICE_PROTOCOL://$SAHARA_SERVICE_HOST:$SAHARA_SERVICE_PORT" \
+        "$SAHARA_SERVICE_PROTOCOL://$SAHARA_SERVICE_HOST:$SAHARA_SERVICE_PORT"
 }
 
 # cleanup_sahara() - Remove residual data files, anything left over from
@@ -206,6 +206,42 @@ function install_sahara {
     fi
 }
 
+# install_ambari() - Collect source and prepare
+function install_ambari {
+    git_clone $AMBARI_PLUGIN_REPO $AMBARI_PLUGIN_DIR $AMBARI_PLUGIN_BRANCH
+    setup_develop $AMBARI_PLUGIN_DIR
+}
+
+# install_cdh() - Collect source and prepare
+function install_cdh {
+    git_clone $CDH_PLUGIN_REPO $CDH_PLUGIN_DIR $CDH_PLUGIN_BRANCH
+    setup_develop $CDH_PLUGIN_DIR
+}
+
+# install_mapr() - Collect source and prepare
+function install_mapr {
+    git_clone $MAPR_PLUGIN_REPO $MAPR_PLUGIN_DIR $MAPR_PLUGIN_BRANCH
+    setup_develop $MAPR_PLUGIN_DIR
+}
+
+# install_spark() - Collect source and prepare
+function install_spark {
+    git_clone $SPARK_PLUGIN_REPO $SPARK_PLUGIN_DIR $SPARK_PLUGIN_BRANCH
+    setup_develop $SPARK_PLUGIN_DIR
+}
+
+# install_storm() - Collect source and prepare
+function install_storm {
+    git_clone $STORM_PLUGIN_REPO $STORM_PLUGIN_DIR $STORM_PLUGIN_BRANCH
+    setup_develop $STORM_PLUGIN_DIR
+}
+
+# install_vanilla() - Collect source and prepare
+function install_vanilla {
+    git_clone $VANILLA_PLUGIN_REPO $VANILLA_PLUGIN_DIR $VANILLA_PLUGIN_BRANCH
+    setup_develop $VANILLA_PLUGIN_DIR
+}
+
 # install_python_saharaclient() - Collect source and prepare
 function install_python_saharaclient {
     if use_library_from_git "python-saharaclient"; then
@@ -228,8 +264,6 @@ function start_sahara {
         restart_apache_server
         tail_log sahara-api /var/log/$APACHE_NAME/sahara-api.log
     else
-        run_process sahara-all "$SAHARA_BIN_DIR/sahara-all \
-            --config-file $SAHARA_CONF_FILE"
         run_process sahara-api "$SAHARA_BIN_DIR/sahara-api \
             --config-file $SAHARA_CONF_FILE"
     fi
@@ -255,7 +289,7 @@ function start_sahara {
 function configure_tempest_for_sahara {
     if is_service_enabled tempest; then
         iniset $TEMPEST_CONFIG service_available sahara True
-        iniset $TEMPEST_CONFIG data-processing-feature-enabled plugins $SAHARA_ENABLED_PLUGINS
+        iniset $TEMPEST_CONFIG data-processing-feature-enabled plugins $SAHARA_INSTALLED_PLUGINS
     fi
 }
 
@@ -276,19 +310,44 @@ function stop_sahara {
 # correctly throughout devstack.
 function is_sahara_enabled {
     if is_service_enabled sahara-api || \
-        is_service_enabled sahara-eng || \
-        is_service_enabled sahara-all; then
+        is_service_enabled sahara-eng; then
         return 0
     else
         return 1
     fi
 }
 
+function is_plugin_required {
+    if [ "${SAHARA_INSTALLED_PLUGINS/$1}" = "$SAHARA_INSTALLED_PLUGINS" ] ; then
+        return 1
+    else
+        return 0
+    fi
+}
+
 # Dispatcher for Sahara plugin
 if is_service_enabled sahara; then
     if [[ "$1" == "stack" && "$2" == "install" ]]; then
         echo_summary "Installing sahara"
         install_sahara
+        if is_plugin_required ambari; then
+            install_ambari
+        fi
+        if is_plugin_required cdh; then
+            install_cdh
+        fi
+        if is_plugin_required mapr; then
+            install_mapr
+        fi
+        if is_plugin_required spark; then
+            install_spark
+        fi
+        if is_plugin_required storm; then
+            install_storm
+        fi
+        if is_plugin_required vanilla; then
+            install_vanilla
+        fi
         install_python_saharaclient
         cleanup_sahara
     elif [[ "$1" == "stack" && "$2" == "post-config" ]]; then
